## Refinement

Refines an ab-initio reconstruction.

This code is mostly a translation from MATLAB code written by Denis Fortun.

#### TO-DO
- [ ] Fix bugs

- [ ] Fix tests, need to generate the matlab data